@@ -15,7 +15,7 @@ with 'WWW::FBX::Role::Auth';
  
 use namespace::autoclean;
 
-our $VERSION="0.09";
+our $VERSION = "0.10";
 
 has lwp_args    => ( isa => 'HashRef', is => 'ro', default => sub { {} } );
 has ua          => ( isa => 'LWP::UserAgent', is => 'rw', lazy => 1, builder => '_build_ua' );
@@ -50,7 +50,7 @@ sub _json_request {
     #And HTTP response RAW
     $self->uarh( $res );
 
-    return $self->uar->{result} ? $self->uar->{result} : {} ;
+    return $self->uar->{result};
 }
  
 sub _prepare_request {
